List

Struct List 

pub struct List<Tag, T: Copy> {
    head: Option<T>,
    tail: Option<T>,
    len: usize,
    _tag: PhantomData<Tag>,
}

Fields

head: Option<T>tail: Option<T>len: usize_tag: PhantomData<Tag>

Implementations

Source

impl<Tag, T: Copy + PartialEq> List<Tag, T>

pub const fn new() -> Self

pub fn head(&self) -> Option<T>

pub fn tail(&self) -> Option<T>

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn push_front<S: Get<T> + GetMut<T>>( &mut self, id: T, storage: &mut S, ) -> Result<(), Error>
where <S as Get<T>>::Output: Linkable<Tag, T>,

pub fn push_back<S: Get<T> + GetMut<T>>( &mut self, id: T, storage: &mut S, ) -> Result<(), Error>
where <S as Get<T>>::Output: Linkable<Tag, T>,

Pushes id to the back of the list. If id is already in the list, it is moved to the back.

Errors if id does not exist in storage or if the node corresponding to id is linked but not in the list.

pub fn pop_front<S: Get<T> + GetMut<T>>( &mut self, storage: &mut S, ) -> Result<Option<T>, Error>
where <S as Get<T>>::Output: Linkable<Tag, T>,

pub fn pop_back<S: Get<T> + GetMut<T>>( &mut self, storage: &mut S, ) -> Result<Option<T>, Error>
where <S as Get<T>>::Output: Linkable<Tag, T>,

pub fn remove<S: Get<T> + GetMut<T>>( &mut self, id: T, storage: &mut S, ) -> Result<(), Error>
where <S as Get<T>>::Output: Linkable<Tag, T>,

Removes id from the list. Errors if id does not exist in storage or if the node corresponding to id is not linked.

Detaches id from any list it is currently in. If id is not in any list but is linked, the links are cleared.